@@ -1,4 +1,6 @@
-import logging
+import logging 
+
+logger = logging.getLogger(__name__)
 
 from datetime import datetime
 
@@ -61,6 +63,7 @@ class NewsletterAdmin(admin.ModelAdmin):
     admin_submissions.short_description = ''
 
 class SubmissionAdmin(admin.ModelAdmin, ExtendibleModelAdminMixin):
+    form = SubmissionAdminForm
     list_display = ('admin_message', 'admin_newsletter', 'admin_publish_date', 'publish', 'admin_status_text', 'admin_status')
     date_hierarchy = 'publish_date'
     list_filter = ('newsletter', 'publish', 'sent')
@@ -377,7 +380,7 @@ class SubscriptionAdmin(admin.ModelAdmin, ExtendibleModelAdminMixin):
             return HttpResponseRedirect('../')
         
         addresses = request.session['addresses']
-        logging.debug('Confirming addresses: %s' % addresses)
+        logger.debug('Confirming addresses: %s' % addresses)
         if request.POST:
             form = ConfirmForm(request.POST)
             if form.is_valid():
